Prot - Pro Tools for Python 3
=============================

Modules
-------

 * **classes**
 * **functions**
 * **converters**
 * **settings**

classes Module
--------------

 * **Database**
 * **OptionsDatabase**
 * **Progress**
 * **ProgressBar** (from **Progress** and **BarWidget**)
 * **LockedDict**
 * **Str**
 * **TextListFile**
 * **Widget**

 >* **TimeWidget**
 >* **BarWidget**
 >* **TaskWidget**
 >* **CallWidget**
 >* **ValueWidget**
 >* **LoadingWidget**

functions Module
----------------

 * **verifyColor**
 * **insertColor**
 * **getRandomPassword**
 * **testSpeed**
 * **getVarFromFile**
 * **checkMethods**
 * **callMethods**
 * **callMethodsWithArg**
 * **checkFileSame**
 * **splitStr**
 * **runAsMain**
 * **printMsg**
 * **printErr**
 * **printWarn**

converters Module
-----------------

 * **rst2html**
 * **dict2matrix**
 * **str2list**
 * **list2str**
 * **matrix2str**

Packages
--------

 * **color**
 * **pip**
 * **progress**
 * **prompt**
 * **wcwidth**

pip Package
-----------

 >this is a Advanced pip Tool, this Package has a List of all pip Packages that you can Search, Download and Install them and you can Update this List anytime you want

 **Features**

 >* it has built in Packages List
 >* you can do an Offline Search
 >* can Create Offline Repositiry
 >* can do Batch Install or Download with built in List or use Custom List
 >* and more...
